Summary: Kernel-based Virtual Machine
Name: kvm
Version: 74
Release: 5%{?dist}
License: GPLv2+ and LGPLv2+
Group: Development/Tools
URL: http://%{name}.sf.net
Source0: http://download.sourceforge.net/sourceforge/%{name}/%{name}-%{version}.tar.gz
#Source0: http://people.qumranet.com:8888/avi/snapshots/kvm-snapshot-%{snapshot}.tar.gz
Source1: %{name}.modules
Patch0: %{name}-bootmenu.patch
Patch1: %{name}-62-block-rw-range-check.patch
Patch2: %{name}-74-pxe-boot.patch
Patch3: %{name}-74-page-find.patch
Patch4: %{name}-fix-pc-bios-make-install-missing-files.patch
# patches from upstream qemu
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
BuildRequires: SDL-devel
# to build the bios
BuildRequires: dev86
BuildRequires: iasl
BuildRequires: zlib-devel
# TLS / x509 auth in VNC server
BuildRequires: gnutls-devel
# for the docs
BuildRequires: texi2html
BuildRequires: rsync
# kvm kernel side is only x86/x86_64 as that's where the hardware is
ExclusiveArch: %{ix86} x86_64 ia64
Requires: initscripts >= 8.08-1

# We use the roms on /usr/share/etherboot
Requires: etherboot-roms-kvm


%description
KVM (for Kernel-based Virtual Machine) is a full virtualization solution
for Linux on x86 hardware.

Using KVM, one can run multiple virtual machines running unmodified Linux
or Windows images. Each virtual machine has private virtualized hardware:
a network card, disk, graphics adapter, etc.

%prep
%setup -q
%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
# we must not use any of the binaries from the qemu/pc-bios/ directory,
# as they don't have the corresponding sources shipped with them
rm -f qemu/pc-bios/*

%build
# systems like rhel build system does not have a recent enough linker so 
# --build-id works. this option is used fedora 8 onwards for giving info
# to the debug packages.

build_id_available() {
	echo "int main () { return 0; }" | gcc -x c -Wl,--build-id - 2>/dev/null
}

if build_id_available; then
	qemuldflags="-Wl,--build-id";
else
	qemuldflags="";
fi

# we need to install the data bits in a different path
sed -i 's/datasuffix=\"\/share\/qemu\"/datasuffix=\"\/share\/kvm\"/' qemu/configure
./configure --with-patched-kernel --kerneldir=$(pwd)/kernel --prefix=%{_prefix} --qemu-ldflags=$qemuldflags \
--audio-drv-list=oss,alsa

# build the bios, and fix it's makefile
sed -i 's/gcc -m32/gcc/' bios/Makefile
make bios

make vgabios

# we can't use RPM_OPT_FLAGS for the same reasons as qemu (#208026) for the
# qemu bits.  so let's set it for the other pieces.  this requires some
# manual keeping up of what is in the kvm tree.
sed -i 's/CFLAGS =/CFLAGS +=/' user/Makefile
echo "CFLAGS=$RPM_OPT_FLAGS" >> user/config.mak
make %{?_smp_mflags}


%install
rm -rf $RPM_BUILD_ROOT
make DESTDIR=$RPM_BUILD_ROOT install

# we have to have our own copies of the bios/keymaps due to incompat with
# qemu 0.9.  include the man page
mv $RPM_BUILD_ROOT/%{_mandir}/man1/qemu.1* $RPM_BUILD_ROOT/%{_mandir}/man1/qemu-kvm.1
rm -rf $RPM_BUILD_ROOT/%{_mandir}/man*/qemu-img* $RPM_BUILD_ROOT/%{_docdir}
rm -f $RPM_BUILD_ROOT/%{_bindir}/qemu-img
# no shared lib, static libs
rm -fr $RPM_BUILD_ROOT/%{_includedir} $RPM_BUILD_ROOT/%{_libdir}

# make install gives it bogus execute permissiions
chmod -x $RPM_BUILD_ROOT/%{_mandir}/man1/qemu-kvm.1*

# We're only build x86, so kill other BIOS to save disk space
rm -f $RPM_BUILD_ROOT/%{_datadir}/%{name}/openbios-sparc32
rm -f $RPM_BUILD_ROOT/%{_datadir}/%{name}/ppc_rom.bin
rm -f $RPM_BUILD_ROOT/%{_datadir}/%{name}/video.x

mv $RPM_BUILD_ROOT/%{_bindir}/qemu-system-x86_64 $RPM_BUILD_ROOT/%{_bindir}/qemu-kvm

mkdir -p $RPM_BUILD_ROOT/%{_sysconfdir}/sysconfig/modules
install -m 0755 %{SOURCE1} $RPM_BUILD_ROOT/%{_sysconfdir}/sysconfig/modules/kvm.modules


# the pxe etherboot images will be symlinks to the images on
# /usr/share/etherboot, as KVM doesn't know how to look
# for other paths, yet.
pxe_link() {
  ln -s ../etherboot/$2.rom %{buildroot}/usr/share/kvm/pxe-$1.bin
}

pxe_link e1000 e1000-82542
pxe_link ne2k_pci ne
pxe_link pcnet pcnet32
pxe_link rtl8139 rtl8139
pxe_link virtio virtio-net


%clean
rm -rf $RPM_BUILD_ROOT


%files
%defattr(-,root,root,-)
%{_bindir}/*
%{_mandir}/*
%{_datadir}/%{name}
%{_sysconfdir}/sysconfig/modules/%{name}.modules

%changelog
* Tue Oct 22 2008 Glauber Costa <glommer@redhat.com> - 74-5
- Remove all prebuilt qemu/pc-bios binaries before building
- Use symlinks to etherboot files for the pxe roms
- Based on the work by Eduardo Habkost

* Mon Sep 15 2008 Glauber Costa <glommer@redhat.com> - 74-4
- fix page_find out of bounds access - #462380

* Tue Sep 09 2008 Glauber Costa <glommer@redhat.com> - 74-3
- fix pxe booting. Needed for oVirt

* Thu Aug 28 2008 Glauber Costa <glommer@redhat.com> - 74-2
- just a tag increase, because CVS is so awesome...

* Thu Aug 28 2008 Glauber Costa <glommer@redhat.com> - 74-1
- Update to newly released kvm-74

* Tue Aug 26 2008 Glauber Costa <glommer@redhat.com> - 73-3.20080825
- Moved forward to yesterday's snapshot. It contains the remaining
  parts of mark's series of GSO patches. It sould be all back to normal
  when kvm-74 is released.

* Tue Aug 26 2008 Glauber Costa <glommer@redhat.com> - 73-2
- updated block rw patch

* Thu Aug 21 2008 Glauber Costa <gcosta@redhat.com> - 73-1
- Update to kvm-73.
- alsa enablement patch not needed anymore - removed.
- Add conditional so we can use this same rpm for rhel.

* Fri Aug 01 2008 Glauber Costa <gcosta@redhat.com> - 72-2
- Remove stubs-32.h BuildRequire. We are building fine without it.

* Mon Jul 28 2008 Glauber Costa <gcosta@redhat.com> - 72-1
- kvm-72

* Tue Jul 22 2008 Glauber Costa <gcosta@redhat.com> - 71-2
- Apply patches correctly.
- Enable ia64.

* Mon Jul 21 2008 Glauber Costa <gcosta@redhat.com> - 71-1
- Update to kvm-71
- --enable-alsa is no more, and kvm-71 seem to have troubles yet to
  be sorted out upstream with parameter passing to qemu. So as a temporary
  quickfix, add kvm-71-alsa.patch to handle it.

* Wed Jun 25 2008 Tomas Mraz <tmraz@redhat.com> - 70-2
- rebuild with new gnutls

* Tue Jun 17 2008 Glauber Costa <gcosta@redhat.com> - 70-1
- Update to kvm-70
- Added qemu-nbd command
- gcc34 build dependency is gone

* Tue May 20 2008 Glauber Costa <gcosta@redhat.com> - 69-1
- Update to kvm-69
- Removed Patch4 (Upstreamed)
- Removed virtio-boot patch (Upstreamed)
- Regenerated the other patches

* Mon May  5 2008 Daniel P. Berrange <berrange@redhat.com> - 68-1
- Update to kvm-68
- Put text console PTY in rawmode

* Tue Apr 29 2008 Mark McLoughlin <markmc@redhat.com> - 65-2
- Fix -kernel with virtio/extboot drives (#444578)

* Tue Apr  8 2008 Jeremy Katz <katzj@redhat.com> - 65-1
- Update to kvm-65 to fix smp instability

* Tue Apr  1 2008 Jeremy Katz <katzj@redhat.com> - 64-3
- and back to rtl8139 to avoid breaking windows guests (#439945)

* Fri Mar 28 2008 Jeremy Katz <katzj@redhat.com> - 64-2
- back to cirrus for video due to bugs with vmwarevga

* Fri Mar 28 2008 Jeremy Katz <katzj@redhat.com> - 64-1
- update to kvm-64

* Fri Mar  7 2008 Jeremy Katz <katzj@redhat.com> - 63-2
- Fix the build

* Wed Mar  5 2008 Jeremy Katz <katzj@redhat.com> - 63-1
- Update to kvm-63

* Tue Mar  4 2008 Kevin Fenzi <kevin@tummy.com> - 62-4
- Make e1000 the default network driver

* Mon Mar  3 2008 Jeremy Katz <katzj@redhat.com> - 62-3
- Default to vmwaresvga now that it's been fixed to work

* Wed Feb 27 2008 Daniel P. Berrange <berrange@redhat.com> - 62-2.fc9
- Fix block device checks for extendable disk formats (rhbz #434978)

* Tue Feb 26 2008 Jeremy Katz <katzj@redhat.com> - 62-1
- Update to kvm-62

* Tue Feb 19 2008 Daniel P. Berrange <berrange@redhat.com> - 61-2.fc9
- Fix block device extents check (rhbz #433560)

* Tue Feb 19 2008 Daniel P. Berrange <berrange@redhat.com> - 61-1.fc9
- Updated to kvm-61

* Tue Feb 19 2008 Fedora Release Engineering <rel-eng@fedoraproject.org> - 60-2
- Autorebuild for GCC 4.3

* Thu Jan 31 2008 Jeremy Katz <katzj@redhat.com> 
- We don't need e2fsprogs-devel to build anymore (#331871)

* Thu Jan 24 2008 Daniel P. Berrange <berrange@redhat.com> - 60-1.fc9
- Updated to kvm-60
- Fix license tag to keep rpmlint quiet
- Remove unused PPC, Sparc and PPC Video BIOS

* Tue Jan 15 2008 Bill Nottingham <notting@redhat.com>: - 59-1
- add upstream patch to fix VMs that no longer boot (#427317)
- update to kvm-59

* Thu Dec 27 2007 Jeremy Katz <katzj@redhat.com> - 58-2
- Fix up defaults patch to apply

* Thu Dec 27 2007 Jeremy Katz <katzj@redhat.com> - 58-1
- Update to kvm-58

* Thu Dec 13 2007 Jeremy Katz <katzj@redhat.com> - 56-1
- Update to kvm-56

* Tue Dec  4 2007 Jeremy Katz <katzj@redhat.com> - 55-1
- Update to kvm-55

* Mon Dec  3 2007 Jeremy Katz <katzj@redhat.com> - 54-1
- update to kvm-54

* Tue Nov 20 2007 Jeremy Katz <katzj@redhat.com> - 53-1
- update to kvm-53

* Wed Nov  7 2007 Jeremy Katz <katzj@redhat.com> - 51-1
- update to kvm-51

* Tue Nov  6 2007 Jeremy Katz <katzj@redhat.com> - 50-1
- update to kvm-50, drop all the patches that have gone upstream

* Mon Oct 15 2007 Daniel P. Berrange <berrange@redhat.com> - 36-7.fc8
- Fixed PXE boot when KVM is enabled (rhbz #331191)

* Wed Sep 26 2007 Daniel P. Berrange <berrange@redhat.com> - 36-6.fc8
- Fixed rtl8139 checksum calculation for Vista (rhbz #308201)

* Mon Sep 24 2007 Jeremy Katz <katzj@redhat.com> - 36-5
- fix build on x86_64

* Mon Sep 24 2007 Jeremy Katz <katzj@redhat.com> - 36-3
- add support for selecting boot device at runtime

* Tue Sep  4 2007 Jeremy Katz <katzj@redhat.com> - 36-2
- rebase vnc auth patch

* Tue Sep  4 2007 Jeremy Katz <katzj@redhat.com> - 36-1
- update to kvm-36

* Mon Aug 27 2007 Daniel P. Berrange <berrange@redhat.com> - 35-3.fc8
- Added patch for VNC password auth and TLS+x509 cert auth

* Mon Aug 20 2007 Jeremy Katz <katzj@redhat.com> - 35-2
- add fix for ATAPI from upstream qemu

* Mon Aug 20 2007 Jeremy Katz <katzj@redhat.com> - 35-1
- update to kvm-35
- patch to use -Wl,--build-id so that we get debuginfo

* Thu Jul 19 2007 Jeremy Katz <katzj@redhat.com> - 31-1
- update to kvm-31

* Mon Jul 16 2007 Jeremy Katz <katzj@redhat.com> - 28-2
- add patch from danpb to fix mac addrs of multiple 8139 nics (#247641)

* Wed Jun 13 2007 Jeremy Katz <katzj@redhat.com> - 28-1
- update to kvm-28

* Sat Jun  9 2007 Jeremy Katz <katzj@redhat.com> - 27-1
- update to kvm-27

* Tue May 29 2007 Jeremy Katz <katzj@redhat.com> - 26-1
- update to kvm-26

* Wed May 16 2007 Jeremy Katz <katzj@redhat.com> - 24-1
- update to kvm-24

* Wed Apr 25 2007 Jeremy Katz <katzj@redhat.com> - 19-2
- fix kernel and ramdisk being specified on the command line (#237879)

* Tue Apr 17 2007 Jeremy Katz <katzj@redhat.com> - 19-1
- update to kvm-19
- use rtl8139 as the default nic emulation instead of ne2k_pci (#236790)

* Mon Mar 26 2007 Jeremy Katz <katzj@redhat.com> - 15-2
- add file so that kvm modules get loaded on boot

* Wed Mar  7 2007 Jeremy Katz <katzj@redhat.com> - 15-1
- update to kvm-15

* Mon Feb 26 2007 Jeremy Katz <katzj@redhat.com> - 14-2
- use default optflags for non-qemu pieces (#230012)

* Fri Feb 23 2007 Jeremy Katz <katzj@redhat.com> - 14-1
- update to kvm-14
- note: this requires a kernel that's 2.6.21-rc1 or newer

* Mon Feb 19 2007 Jeremy Katz <katzj@redhat.com> - 12-3
- add the buildrequires for the docs to build

* Mon Feb 19 2007 Jeremy Katz <katzj@redhat.com> - 12-2
- include bios and keymaps in the kvm package since we need a slightly 
  different version for kvm now
- include man page

* Fri Jan 26 2007 Jeremy Katz <katzj@redhat.com> - 12-1
- update to kvm-12
- add qemu patch for better ATAPI DMA support (which works with ata_piix)

* Fri Jan 19 2007 Jeremy Katz <katzj@redhat.com> - 11-1
- update to kvm-11

* Fri Jan  5 2007 Jeremy Katz <katzj@redhat.com> - 9-1
- update to kvm-9

* Wed Jan  3 2007 Jeremy Katz <katzj@redhat.com> - 7-4
- actually build without -devel...

* Wed Dec 20 2006 Jeremy Katz <katzj@redhat.com> - 7-3
- remove the -devel subpackage since there's no shared lib upstream yet
- direct download link for source 

* Tue Dec 19 2006 Jeremy Katz <katzj@redhat.com> - 7-2
- BR e2fsprogs-devel

* Tue Dec 19 2006 Jeremy Katz <katzj@redhat.com> - 7-1
- Initial build 

